@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -423,7 +423,7 @@ class Backup(Subcommand):
 
             # borg prune
             cmd = [borg, 'prune',
-                   '--prefix', '{}-'.format(hostname)] + keep
+                   '--glob-archives', '{}-*'.format(hostname)] + keep
             if self.verbose:
                 cmd.extend([
                     '--list',
