@@ -3,13 +3,12 @@
 Alembic Environment Script
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 from alembic import context
 from sqlalchemy.orm import configure_mappers
 
 from rattail.config import make_config
-from rattail.db.util import get_default_engine
 from rattail.db.continuum import configure_versioning
 
 
@@ -22,7 +21,7 @@ rattail_config = make_config(alembic_config.config_file_name, versioning=False)
 
 # Configure Continuum...this is trickier than I'd like.
 configure_versioning(rattail_config, force=True)
-from rattail.db import model
+model = rattail_config.get_model()
 configure_mappers()
 
 # add your model's MetaData object here
@@ -42,7 +41,7 @@ def run_migrations_offline():
     script output.
 
     """
-    engine = get_default_engine(rattail_config)
+    engine = rattail_config.rattail_engine
     context.configure(
         url=engine.url,
         target_metadata=target_metadata)
@@ -58,7 +57,7 @@ def run_migrations_online():
     and associate a connection with the context.
 
     """
-    engine = get_default_engine(rattail_config)
+    engine = rattail_config.rattail_engine
     connection = engine.connect()
     context.configure(
         connection=connection,
