@@ -29,7 +29,8 @@ def upgrade():
                     sa.Column('user_uuid', sa.String(length=32), nullable=False),
                     sa.Column('type_code', sa.Integer(), nullable=False),
                     sa.Column('occurred', sa.DateTime(), nullable=True),
-                    sa.ForeignKeyConstraint(['user_uuid'], [u'user.uuid'], name=u'user_x_role_fk_user'),
+                    sa.ForeignKeyConstraint(['user_uuid'], ['user.uuid'],
+                                            name='user_event_fk_user'),
                     sa.PrimaryKeyConstraint('uuid')
     )
 
