@@ -30,10 +30,16 @@ from __future__ import unicode_literals, absolute_import
 class Setting(object):
     """
     Base class for all setting definitions.
+
+    .. attribute:: core
+
+       Boolean indicating if this is a "core setting" - i.e. one which
+       should be exposed in the App Settings in most/all apps.
     """
     group = "(General)"
     namespace = None
     name = None
+    core = False
     data_type = str
     choices = None
     required = False
@@ -49,6 +55,29 @@ class rattail_app_title(Setting):
     """
     namespace = 'rattail'
     name = 'app_title'
+    core = True
+
+
+class rattail_app_class_prefix(Setting):
+    """
+    App-specific "capwords-style" prefix, used for naming model
+    classes and other things.  E.g. with prefix of 'Poser', model
+    might be named 'PoserWidget'.
+    """
+    namespace = 'rattail'
+    name = 'app_class_prefix'
+    core = True
+
+
+class rattail_app_table_prefix(Setting):
+    """
+    App-specific "variable-style" prefix, used for naming tables and
+    other things.  E.g. with prefix of 'poser', table might be named
+    'poser_widget'.
+    """
+    namespace = 'rattail'
+    name = 'app_table_prefix'
+    core = True
 
 
 class rattail_node_title(Setting):
@@ -68,6 +97,7 @@ class rattail_production(Setting):
     namespace = 'rattail'
     name = 'production'
     data_type = bool
+    core = True
 
 
 class tailbone_background_color(Setting):
@@ -81,11 +111,22 @@ class tailbone_background_color(Setting):
 class tailbone_buefy_version(Setting):
     """
     Version of the Buefy component JS library to use for "falafel"
-    based themes.  The minimum should be '0.8.6' or probably even
-    '0.8.13', but feel free to experiment.
+    based themes.  The old recommendation was to use '0.8.17' but now
+    anything from 0.9.x or later should be supported.  See what's
+    available at https://github.com/buefy/buefy/releases
     """
     namespace = 'tailbone'
     name = 'buefy_version'
+    core = True
+
+
+class tailbone_favicon_url(Setting):
+    """
+    URL of favicon image.
+    """
+    namespace = 'tailbone'
+    name = 'favicon_url'
+    core = True
 
 
 class tailbone_feedback_allows_reply(Setting):
@@ -105,6 +146,25 @@ class tailbone_grid_default_pagesize(Setting):
     namespace = 'tailbone'
     name = 'grid.default_pagesize'
     data_type = int
+    core = True
+
+
+class tailbone_header_image_url(Setting):
+    """
+    URL of smaller logo image, shown in menu header.
+    """
+    namespace = 'tailbone'
+    name = 'header_image_url'
+    core = True
+
+
+class tailbone_main_image_url(Setting):
+    """
+    URL of main app logo image, e.g. on home/login page.
+    """
+    namespace = 'tailbone'
+    name = 'main_image_url'
+    core = True
 
 
 class tailbone_sticky_headers(Setting):
@@ -127,6 +187,7 @@ class tailbone_vue_version(Setting):
     """
     namespace = 'tailbone'
     name = 'vue_version'
+    core = True
 
 
 class rattail_single_store(Setting):
